========
XML Diff
========

.. image:: https://travis-ci.org/Shoobx/xmldiff.png?branch=master
   :target: https://travis-ci.org/Shoobx/xmldiff

.. image:: https://coveralls.io/repos/github/Shoobx/xmldiff/badge.svg?branch=master
   :target: https://coveralls.io/github/Shoobx/xmldiff?branch=master

.. image:: https://img.shields.io/pypi/v/xmldiff.svg
    :target: https://pypi.python.org/pypi/xmldiff

.. image:: https://img.shields.io/pypi/pyversions/xmldiff.svg
    :target: https://pypi.python.org/pypi/xmldiff/


Xmldiff is a utility for extracting differences between two xml files. It
returns a set of primitives to apply on source tree to obtain the destination
tree.

The implementation is based on `Change detection in hierarchically structured
information`, by S. Chawathe, A. Rajaraman, H. Garcia-Molina and J. Widom,
Stanford University, 1996
